@@ -3,7 +3,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp qw/croak/;
 use Array::Diff;
@@ -27,6 +27,7 @@ my @rev_column_sugars = qw/not_null signed/;
 my @export_dsls = qw/
     create_database database    create_table    column      primary_key set_primary_key add_index   add_unique_index
     foreign_key     has_many    has_one         belongs_to  add_table_options   default_unsigned    columns pk  fk
+    default_not_null
 /;
 my @class_methods = qw/context output no_fk_output translate_to translator/;
 sub import {
@@ -59,6 +60,10 @@ sub default_unsigned() {
     caller->context->default_unsigned(1);
 }
 
+sub default_not_null() {
+    caller->context->default_not_null(1);
+}
+
 sub create_table($$) {
     my ($table_name, $code) = @_;
 
@@ -163,6 +168,11 @@ sub column($$;%) {
         $args{extra}{unsigned} = 1;
     }
 
+    if ( !exists $args{$map{null}} && $c->default_not_null ) {
+        my $val = not_null();
+        $args{$map{null}} = $val;
+    }
+
     if ($args{data_type} eq 'VARCHAR' && !$args{size}) {
         $args{size} = $c->default_varchar_size;
     }
@@ -340,7 +350,7 @@ DBIx::Schema::DSL - DSL for Database schema declaration
 
 =head1 VERSION
 
-This document describes DBIx::Schema::DSL version 0.06.
+This document describes DBIx::Schema::DSL version 0.07.
 
 =head1 SYNOPSIS
 
@@ -411,6 +421,11 @@ Set global setting of table->extra for SQL::Translator::Table
 Automatically set unsigned when declaring integer columns.
 If you want to declare singed columns, using `singed` sugar.
 
+=head3 C<< default_not_null() >>
+
+Automatically set not null.
+If you want to declare null columns, using `null` sugar.
+
 =head3 C<< create_table($table_name :Str, $columns :CodeRef) >>
 
 Declare table.
